@@ -449,8 +449,10 @@ class Model:
                     fun = lambda: value
                 super().__setattr__(key, self._get_signal_function(key, fun))
             else:
-                assert key not in self._vars, "Not allowed to redefine vars. Define them as inputs if you want to " \
-                                              "assign them after the constructor. "
+                msg = """Not allowed to redefine vars. 
+                Either define them as inputs if you want to assign them after the constructor; 
+                or define a new python field that can be assigned and read by the variable function."""
+                assert key not in self._vars, msg
                 super().__setattr__(key, value)
 
     @staticmethod
